@@ -10,6 +10,8 @@ describe 'glance::backend::file' do
     end
 
     it 'configures glance-cache.conf' do
+      is_expected.to contain_glance_cache_config('glance_store/default_store').with_value('file')
+      is_expected.to contain_glance_cache_config('glance_store/filesystem_thin_provisioning').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_glance_cache_config('glance_store/filesystem_store_datadir').with_value('/var/lib/glance/images/')
     end
 
@@ -28,6 +30,7 @@ describe 'glance::backend::file' do
 
       it 'configures glance-cache.conf' do
         is_expected.to contain_glance_cache_config('glance_store/filesystem_store_datadir').with_value('/tmp/')
+        is_expected.to contain_glance_cache_config('glance_store/filesystem_thin_provisioning').with_value('true')
       end
 
     end
