@@ -8,6 +8,7 @@ describe 'glance::notify::rabbitmq' do
         :heartbeat_timeout_threshold     => '<SERVICE DEFAULT>',
         :heartbeat_rate                  => '<SERVICE DEFAULT>',
         :heartbeat_in_pthread            => '<SERVICE DEFAULT>',
+        :rabbit_qos_prefetch_count       => '<SERVICE DEFAULT>',
         :rabbit_use_ssl                  => '<SERVICE DEFAULT>',
         :kombu_ssl_ca_certs              => '<SERVICE DEFAULT>',
         :kombu_ssl_certfile              => '<SERVICE DEFAULT>',
@@ -22,6 +23,7 @@ describe 'glance::notify::rabbitmq' do
         :rabbit_quorum_delivery_limit    => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_length => '<SERVICE DEFAULT>',
         :rabbit_quorum_max_memory_bytes  => '<SERVICE DEFAULT>',
+        :enable_cancel_on_failover       => '<SERVICE DEFAULT>',
       ) }
 
       it { is_expected.to contain_oslo__messaging__default('glance_api_config').with(
@@ -35,6 +37,7 @@ describe 'glance::notify::rabbitmq' do
         :driver        => '<SERVICE DEFAULT>',
         :transport_url => '<SERVICE DEFAULT>',
         :topics        => '<SERVICE DEFAULT>',
+        :retry         => '<SERVICE DEFAULT>',
       ) }
     end
 
@@ -45,16 +48,17 @@ describe 'glance::notify::rabbitmq' do
           :rpc_response_timeout               => '120',
           :control_exchange                   => 'glance',
           :executor_thread_pool_size          => 64,
-          :notification_transport_url         => 'rabbit://user:pass@alt_host:1234/virt',
           :rabbit_ha_queues                   => true,
           :rabbit_heartbeat_timeout_threshold => '60',
           :rabbit_heartbeat_rate              => '10',
           :rabbit_heartbeat_in_pthread        => true,
+          :rabbit_qos_prefetch_count          => 0,
           :rabbit_quorum_queue                => true,
           :rabbit_transient_quorum_queue      => true,
           :rabbit_quorum_delivery_limit       => 3,
           :rabbit_quorum_max_memory_length    => 5,
           :rabbit_quorum_max_memory_bytes     => 1073741824,
+          :rabbit_enable_cancel_on_failover   => false,
           :rabbit_use_ssl                     => true,
           :kombu_ssl_ca_certs                 => '/etc/ca.cert',
           :kombu_ssl_certfile                 => '/etc/certfile',
@@ -62,10 +66,12 @@ describe 'glance::notify::rabbitmq' do
           :kombu_ssl_version                  => 'TLSv1',
           :kombu_reconnect_delay              => '5.0',
           :kombu_failover_strategy            => 'shuffle',
-          :rabbit_notification_topic          => 'notification',
           :amqp_durable_queues                => true,
           :kombu_compression                  => 'gzip',
+          :notification_transport_url         => 'rabbit://user:pass@alt_host:1234/virt',
+          :notification_topics                => 'notification',
           :notification_driver                => 'messagingv2',
+          :notification_retry                 => 10,
         }
       end
 
@@ -74,6 +80,7 @@ describe 'glance::notify::rabbitmq' do
         :heartbeat_timeout_threshold     => '60',
         :heartbeat_rate                  => '10',
         :heartbeat_in_pthread            => true,
+        :rabbit_qos_prefetch_count       => 0,
         :rabbit_use_ssl                  => true,
         :kombu_ssl_ca_certs              => '/etc/ca.cert',
         :kombu_ssl_certfile              => '/etc/certfile',
@@ -88,6 +95,7 @@ describe 'glance::notify::rabbitmq' do
         :rabbit_quorum_delivery_limit    => 3,
         :rabbit_quorum_max_memory_length => 5,
         :rabbit_quorum_max_memory_bytes  => 1073741824,
+        :enable_cancel_on_failover       => false,
       ) }
 
       it { is_expected.to contain_oslo__messaging__default('glance_api_config').with(
@@ -101,6 +109,7 @@ describe 'glance::notify::rabbitmq' do
         :driver        => 'messagingv2',
         :transport_url => 'rabbit://user:pass@alt_host:1234/virt',
         :topics        => 'notification',
+        :retry         => 10,
       ) }
     end
   end
